! ###########################################################
!            Satellite Data Simulation Unit v2
!                    - RDRparameters -
!
! This module defines variables used for the radar simulator.
!
 Module RDRparameters
   Implicit NONE
!
! dBZ: radar reflectivity
! PIA: 2-way path integrated attenuation
!
   real, dimension(:,:,:), allocatable :: dBZ
   real, dimension(:,:),   allocatable :: PIA
!
! kext: extinction coefficient
! sabl: single scattering albedo
! pbck: back-scattering coefficient
!
   real, dimension(:,:,:), allocatable :: kexttot,salbtot,sbacktot
!
! kext, salb, and pbck stored in the LUT for rain (rr), cloud ice (ci),
! cloud water (cw), snow (sn), graupel (gr), hail (hl), and melting
! particles (ml).
!
   real, dimension(:,:,:), allocatable :: kextrr_lut,salbrr_lut,pbckrr_lut
   real, dimension(:,:,:), allocatable :: kextci_lut,salbci_lut,pbckci_lut
   real, dimension(:,:,:), allocatable :: kextcw_lut,salbcw_lut,pbckcw_lut
   real, dimension(:,:,:), allocatable :: kextsn_lut,salbsn_lut,pbcksn_lut
   real, dimension(:,:,:), allocatable :: kextgr_lut,salbgr_lut,pbckgr_lut
   real, dimension(:,:,:), allocatable :: kexthl_lut,salbhl_lut,pbckhl_lut
   real, dimension(:,:,:), allocatable :: kextml_lut,salbml_lut,pbckml_lut
!
! / Updated for SDSU v.2.1.0 /
! pts_hydro  : LUT hydrometeor water content vector (in [g/m3])
! ptn_????   : LUT hydrometeor number concentration vector (in [/m3])
!              ????=cldi, cldw, rain, snow, grpl, or hail
! pts_temp_w : LUT temperature vector (in [K]) for liquid hydrometeors
! pts_temp_i : LUT temperature vector (in [K]) for frozen hydrometeors
! npts_hydro : LUT hydrometeor water content dimension size
! npts_temp  : LUT temperature dimension size
! npts_ncnc  : LUT hydrometeor number concentration dimension size
! ( These parameters will be read in from the LUTs. )
!
   real, dimension(:), allocatable :: pts_hydro, pts_temp_w, pts_temp_i
   real, dimension(:), allocatable :: ptn_cldi, ptn_cldw, ptn_rain
   real, dimension(:), allocatable :: ptn_snow, ptn_grpl, ptn_hail
   integer :: npts_hydro, npts_temp, npts_ncnc
!
! Miscellaneous
!
   real :: umu
!
 End Module RDRparameters
 
