! ############################################################
!            Satellite Data Simulation Unit v2
!                     -  SIMradar -
!
! Radar Simulator
!
!                 Updated from SIMradar.f by H. M. (May, 2009)
!                 Updated for SDSUv2.1.0  by H. M. (Aug, 2009)
!                       with mie_lut_rdr thoroughly rewritten.
!
 Subroutine SIMradar
   Use MAINparameters
   Use RDRparameters
   Implicit NONE
!
   Interface
      Subroutine mie_lut_rdr ( Whydr,x1,x2,pts_x1,pts_x2, &
                               y1lut,y2lut,y3lut,y1,y2,y3 )
        Real, intent(in) :: x1,x2,Whydr
        Real, intent(in) :: pts_x1(:),pts_x2(:)
        Real, intent(in) :: y1lut(:,:,:),y2lut(:,:,:),y3lut(:,:,:)
        Real, intent(out) :: y1,y2,y3
      End Subroutine mie_lut_rdr
   End Interface
!
   real, dimension(:), allocatable :: atm_ext
   real, dimension(:), allocatable :: kextcw,salbcw,asymcw,pbckcw
   real, dimension(:), allocatable :: kextrr,salbrr,asymrr,pbckrr
   real, dimension(:), allocatable :: kextci,salbci,asymci,pbckci
   real, dimension(:), allocatable :: kextsn,salbsn,asymsn,pbcksn
   real, dimension(:), allocatable :: kextgr,salbgr,asymgr,pbckgr
   real, dimension(:), allocatable :: kexthl,salbhl,asymhl,pbckhl
   real, dimension(:), allocatable :: kextml,salbml,asymml,pbckml
!
   real :: Tavg, Pres
!
   real :: freqcy,f_frz
   integer, dimension(:,:), allocatable :: nzfrz
   real,    dimension(:), allocatable :: f_mlt
   logical, dimension(:), allocatable :: calc_melt
!
   integer :: nx, ny, nz
   integer :: nf
!
   umu = cos(inc_angle_rdr*3.141593/180.)
   allocate ( nzfrz(ngridx,ngridy), f_mlt(nlyr) )
   allocate ( calc_melt(nlyr) )
!
   allocate( dBZ(ngridx,ngridy,nlyr),dBZ_out(mxfreq_radar,ngridx,ngridy,nlyr) )
   allocate( PIA(ngridx,ngridy), PIA_out(mxfreq_radar,ngridx,ngridy) )
!
   allocate ( atm_ext(nlyr) )
   allocate ( kextcw(nlyr), salbcw(nlyr), asymcw(nlyr), pbckcw(nlyr) )
   allocate ( kextrr(nlyr), salbrr(nlyr), asymrr(nlyr), pbckrr(nlyr) )
   allocate ( kextci(nlyr), salbci(nlyr), asymci(nlyr), pbckci(nlyr) )
   allocate ( kextsn(nlyr), salbsn(nlyr), asymsn(nlyr), pbcksn(nlyr) )
   allocate ( kextgr(nlyr), salbgr(nlyr), asymgr(nlyr), pbckgr(nlyr) )
   allocate ( kexthl(nlyr), salbhl(nlyr), asymhl(nlyr), pbckhl(nlyr) )
   allocate ( kextml(nlyr), salbml(nlyr), asymml(nlyr), pbckml(nlyr) )
   allocate ( kexttot(ngridx,ngridy,nlyr) )
   allocate ( sbacktot(ngridx,ngridy,nlyr) )
!
! Identify the freezing level
!
   do nx = 1, ngridx
      do ny = 1, ngridy
! / Added for SDSU v2.1.1 /
         nzfrz(nx,ny) = 0
         do nz = 1,nlyr
            if (temp_lev(nx,ny,nz-1) >= 273.16 .and. &
                temp_lev(nx,ny,nz)   <= 273.16) then
               nzfrz(nx,ny) = nz
               Exit
            endif
         end do
      end do
   end do
!
   print *, '/// Radar simulation ///'
   do nf = 1, mxfreq_radar
!
      freqcy = freq_radar(nf)
      print '(A,I2,A,F6.3,A)', ' nfreq: ',nf,' at ',freqcy,' GHz'
!
! Read in the Mie LUT
!
      If ( lut ) Call open_lut_rdr ( nf )
!
! --- Calculate optical properties of each volume element of the cloud  ---
!
      do nx = 1, ngridx
      do ny = 1, ngridy
!
! initialization
!
         kextrr = 0. ; salbrr = 0. ; pbckrr = 0.
         kextci = 0. ; salbci = 0. ; pbckci = 0.
         kextcw = 0. ; salbcw = 0. ; pbckcw = 0.
         kextsn = 0. ; salbsn = 0. ; pbcksn = 0.
         kextgr = 0. ; salbgr = 0. ; pbckgr = 0.
         kexthl = 0. ; salbhl = 0. ; pbckhl = 0.
         kextml = 0. ; salbml = 0. ; pbckml = 0.
         f_mlt  = 0.
!
         If ( nzfrz(nx,ny) > 1 ) then
!
            f_frz = (temp_lev(nx,ny,nzfrz(nx,ny)-1) - 273.16) / &
                    (temp_lev(nx,ny,nzfrz(nx,ny)-1) -           &
                     temp_lev(nx,ny,nzfrz(nx,ny)))
            f_mlt(nzfrz(nx,ny))   = f_frz
            f_mlt(nzfrz(nx,ny)-1) = 1.-f_frz
!
         Endif
!
         do nz = 1, nlyr
            Tavg = 0.5*( temp_lev(nx,ny,nz-1) + temp_lev(nx,ny,nz) )
!
! / Modified for SDSUv2.1.0 /
!
            Pres = 0.5*( pres_lev(nx,ny,nz-1) + pres_lev(nx,ny,nz) )
!
!            Pres =(pres_lev(nx,ny,nz) - pres_lev(nx,ny,nz-1) ) / &
!               log(pres_lev(nx,ny,nz) / pres_lev(nx,ny,nz-1))
!
! Gas absorption code updated (11/06/03), provided by Chris Kummerow.
!           
            call absorb(freqcy, Tavg, Pres, &
                        rlhm_avg(nx,ny,nz), 0., atm_ext(nz))
!
            If ( lut ) then
!
! Find the radiative properties in LUT
!
               Call mie_lut_rdr (Wrain_avg(nx,ny,nz),Tavg, &
                                 Nrain_avg(nx,ny,nz),pts_temp_w,ptn_rain, &
                                 kextrr_lut,salbrr_lut,pbckrr_lut, &
                                 kextrr(nz),salbrr(nz),pbckrr(nz))
!
               Call mie_lut_rdr (Wcldi_avg(nx,ny,nz),Tavg, &
                                 Ncldi_avg(nx,ny,nz),pts_temp_i,ptn_cldi, &
                                 kextci_lut,salbci_lut,pbckci_lut, &
                                 kextci(nz),salbci(nz),pbckci(nz))
!
               Call mie_lut_rdr (Wcldw_avg(nx,ny,nz),Tavg, &
                                 Ncldw_avg(nx,ny,nz),pts_temp_w,ptn_cldw, &
                                 kextcw_lut,salbcw_lut,pbckcw_lut, &
                                 kextcw(nz),salbcw(nz),pbckcw(nz))
!
               Call mie_lut_rdr (Wsnow_avg(nx,ny,nz),Tavg, &
                                 Nsnow_avg(nx,ny,nz),pts_temp_i,ptn_snow, &
                                 kextsn_lut,salbsn_lut,pbcksn_lut, &
                                 kextsn(nz),salbsn(nz),pbcksn(nz))
!
               Call mie_lut_rdr (Wgrpl_avg(nx,ny,nz),Tavg, &
                                 Ngrpl_avg(nx,ny,nz),pts_temp_i,ptn_grpl, &
                                 kextgr_lut,salbgr_lut,pbckgr_lut, &
                                 kextgr(nz),salbgr(nz),pbckgr(nz))
!
               Call mie_lut_rdr (Whail_avg(nx,ny,nz),Tavg, &
                                 Nhail_avg(nx,ny,nz),pts_temp_i,ptn_hail, &
                                 kexthl_lut,salbhl_lut,pbckhl_lut, &
                                 kexthl(nz),salbhl(nz),pbckhl(nz))
!
! In case without LUT
!
            Else
!
               call mie_cldw( freqcy,Tavg,Wcldw_avg(nx,ny,nz), &
                                          Ncldw_avg(nx,ny,nz), &
                              kextcw(nz),salbcw(nz),asymcw(nz),pbckcw(nz))
!
               call mie_rain( freqcy,Tavg,Wrain_avg(nx,ny,nz), &
                                          Nrain_avg(nx,ny,nz), &
                              kextrr(nz),salbrr(nz),asymrr(nz),pbckrr(nz))
!
               call mie_cldi( freqcy,Tavg,Wcldi_avg(nx,ny,nz), &
                                          Ncldi_avg(nx,ny,nz), &
                              kextci(nz),salbci(nz),asymci(nz),pbckci(nz))
!
               call mie_snow( freqcy,Tavg,Wsnow_avg(nx,ny,nz), &
                                          Nsnow_avg(nx,ny,nz), &
                              kextsn(nz),salbsn(nz),asymsn(nz),pbcksn(nz))
!
               call mie_grpl( freqcy,Tavg,Wgrpl_avg(nx,ny,nz), &
                                          Ngrpl_avg(nx,ny,nz), &
                              kextgr(nz),salbgr(nz),asymgr(nz),pbckgr(nz))
!
               call mie_hail( freqcy,Tavg,Whail_avg(nx,ny,nz), &
                                          Nhail_avg(nx,ny,nz), &
                              kexthl(nz),salbhl(nz),asymhl(nz),pbckhl(nz))
!
            Endif
!
         end do
!
! Sum up the absorption/scattering parameters
!
         kexttot(nx,ny,:) = atm_ext + kextcw + kextrr + kextci + &
                             kextsn + kextgr + kexthl
         sbacktot(nx,ny,:) = pbckcw*salbcw*kextcw + pbckrr*salbrr*kextrr + &
                             pbckci*salbci*kextci + pbcksn*salbsn*kextsn + &
                             pbckgr*salbgr*kextgr + pbckhl*salbhl*kexthl
!
! --- Simplified treatment of melting particles ---
! --- applied only to stratiform rains (ics=2)  ---
!
         calc_melt = .false.
!
         If ( nzfrz(nx,ny) > 1 ) then
            calc_melt(nzfrz(nx,ny)  ) = ics(nx,ny) == 2
            calc_melt(nzfrz(nx,ny)-1) = ics(nx,ny) == 2
! / Added for SDSU v2.1.1 /
         Else
            cycle
         Endif
         If ( ics(nx,ny) /= 2 ) cycle
         If ( .not. meltp ) cycle
!
         do nz = nzfrz(nx,ny)-1, nzfrz(nx,ny)
!
            If ( lut ) then
!
               Call mie_lut_rdr (Wrain_avg(nx,ny,nz)+Wsnow_avg(nx,ny,nz), &
                                 Nrain_avg(nx,ny,nz),Nsnow_avg(nx,ny,nz), &
                                 ptn_rain,ptn_snow, &
                                 kextml_lut,salbml_lut,pbckml_lut, &
                                 kextml(nz),salbml(nz),pbckml(nz))
!              
            Else
!
               Call df_mie_melt(freqcy, &
                                Wrain_avg(nx,ny,nz), Wsnow_avg(nx,ny,nz), &
                                Nrain_avg(nx,ny,nz), Nsnow_avg(nx,ny,nz), &
                                kextml(nz),pbckml(nz),salbml(nz),pbckml(nz))
!
            Endif
!
         end do
!
         where ( calc_melt .and. meltp )
!
            kextml = f_mlt*kextml + (1.-f_mlt)*(kextrr + kextsn)
            where ( kextml > 1.e-20)
               salbml = (f_mlt*salbml*kextml + (1.-f_mlt) * &
                        (salbrr*kextrr + salbsn*kextsn)) / kextml
            elsewhere
               salbml = 0.
            endwhere
            where ( salbml > 1.e-20 ) 
               pbckml = (f_mlt*pbckml*salbml*kextml + (1.-f_mlt) * &
                        (pbckrr*salbrr*kextrr + pbcksn*salbsn*kextsn)) / &
                        (salbml*kextml)
            elsewhere
               pbckml = 0.
            endwhere
!
            kexttot(nx,ny,:) = atm_ext + kextml + kextcw + &
                                kextci + kextgr + kexthl
            sbacktot(nx,ny,:) = pbckcw*salbcw*kextcw + pbckci*salbci*kextci + &
                                pbckml*salbml*kextml + pbckgr*salbgr*kextgr + &
                                pbckhl*salbhl*kexthl
!
         endwhere
!
      end do ! ends ngridy loop
      end do ! ends ngridx loop
!
! --- Calculate radar reflectivity and PIA ---
!
      Call radar_echo ( freqcy )
!
      dBZ_out(nf,:,:,:) = dBZ
      PIA_out(nf,:,:)   = PIA
 !
      If ( lut ) then
!
         deallocate ( kextcw_lut, salbcw_lut, pbckcw_lut )
         deallocate ( kextrr_lut, salbrr_lut, pbckrr_lut )
         deallocate ( kextci_lut, salbci_lut, pbckci_lut )
         deallocate ( kextsn_lut, salbsn_lut, pbcksn_lut )
         deallocate ( kextgr_lut, salbgr_lut, pbckgr_lut )
         deallocate ( kexthl_lut, salbhl_lut, pbckhl_lut )
         If ( meltp ) &
         deallocate ( kextml_lut, salbml_lut, pbckml_lut )
         deallocate ( pts_hydro, pts_temp_i, pts_temp_w  )
         deallocate ( ptn_cldi, ptn_cldw, ptn_rain )
         deallocate ( ptn_snow, ptn_grpl, ptn_hail )
!
      Endif
!
   end do ! ends loop over frequency
!
   deallocate ( atm_ext )
   deallocate ( kextcw, salbcw, asymcw, kextrr, salbrr, asymrr )
   deallocate ( kextci, salbci, asymci, kextsn, salbsn, asymsn )
   deallocate ( kextgr, salbgr, asymgr, kexthl, salbhl, asymhl )
   deallocate ( kextml, salbml, asymml, kexttot, sbacktot )
   deallocate ( pbckcw, pbckrr, pbckci, pbcksn, pbckgr, pbckhl, pbckml )
   deallocate ( nzfrz, f_mlt, calc_melt )
   deallocate ( dBZ, PIA )
!
   Return
 End Subroutine SIMradar
