! ############################################################
!            Satellite Data Simulation Unit v2
!                     -  out_radar -
!
! This subroutine writes out the computed radar dBZ and PIA
!
!                 Updated from out-radar.f by H. M. (May, 2009)
!
 Subroutine out_radar ( ifile )
   Use MAINparameters
   Use MCRPparameters
   Implicit NONE
!
! I/O parameters
!
   Integer, intent(in) :: ifile
!
! Local variables
!
   Integer :: i,j,l,k
   character*90 :: pathandfile, filename
!
   filename = CRM_file_list(ifile)
!
! Data dimensions in ascii format
!
   pathandfile = outputdir//trim(filename)//'.rdr.info'
   open(unit= 16, file = pathandfile, form = 'formatted')
!
   write(16,51) ngridx, ngridy, nlyr, deltax, deltay
   write(16,*) 'viewing angle:',inc_angle_rdr
   write(16,*) mxfreq_radar,'frequencies at', freq_radar,' GHz.'
!
   write(16,*) '/ Microphysical setup /'
   write(16,*) ' - Cloud ice: ',trim(cldi%name)//'('//cldi%functype//')'
   Do i = 1, cldi%nparams
      write(16,52) '  PSD parameter #',i,'=',cldi%paramset(i)
   End do
   write(16,*) ' - Cloud water: ',trim(cldw%name)//'('//cldw%functype//')'
   Do i = 1, cldw%nparams
      write(16,52) '  PSD parameter #',i,'=',cldw%paramset(i)
   End do
   write(16,*) ' - Rain: ',trim(rain%name)//'('//rain%functype//')'
   Do i = 1, rain%nparams
      write(16,52) '  PSD parameter #',i,'=',rain%paramset(i)
   End do
   write(16,*) ' - Snow: ',trim(snow%name)//'('//snow%functype//')'
   Do i = 1, snow%nparams
      write(16,52) '  PSD parameter #',i,'=',snow%paramset(i)
   End do
   write(16,*) ' - Graupel: ',trim(grpl%name)//'('//grpl%functype//')'
   Do i = 1, grpl%nparams
      write(16,52) '  PSD parameter #',i,'=',grpl%paramset(i)
   End do
   write(16,*) ' - Hail: ',trim(hail%name)//'('//hail%functype//')'
   Do i = 1, hail%nparams
      write(16,52) '  PSD parameter #',i,'=',hail%paramset(i)
   End do
!
! Computed Tbs in binary format
!
   pathandfile = outputdir//trim(filename)//'.rdr.org'
   open(unit= 21, file = pathandfile, access = 'direct', &
        recl = (nlyr+1)*ngridx*ngridy*mxfreq_radar*4)
!
   write(21,rec=1) ((((dBZ_out(l,i,j,k),i=1,ngridx),j=1,ngridy) &
                                                     ,k=1,nlyr),&
                     ((PIA_out(l,i,j)  ,i=1,ngridx),j=1,ngridy) &
                                             ,l=1,mxfreq_radar)
!
51 format(i3,' x ',i3,' (x,y) grid; ',i3,' layers; ', &
             ' deltax = ',f6.2,' km','  deltay = ',f6.2,' km')
52 format(a,i2,a,1P1e10.3)
!
   Close (16)
   Close (21)
   If ( .not. beamconv ) deallocate ( dBZ_out, PIA_out )
!
   Return
 End Subroutine out_radar

